@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/rational.c,v 1.29 2004/02/27 03:50:16 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/rational.c,v 1.30 2005/06/05 01:03:42 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -417,8 +417,8 @@ IntPowMod (int a, int p, int m)
 
     if (m >= 32767)
     {
-#if SIZEOF_LONG_LONG == 8
-	long long   la = a, lm = m, lr;
+#if DIGITBITS == 32
+	signed_digit   la = a, lm = m, lr;
 	lr = 1;
 	while (p)
 	{
