@@ -1,4 +1,4 @@
-/* $Header: /local/src/CVS/nickle/sched.c,v 1.59 2004/12/11 06:02:23 keithp Exp $ */
+/* $Header: /local/src/CVS/nickle/sched.c,v 1.60 2005/01/14 05:44:00 keithp Exp $ */
 
 /*
  * Copyright © 1988-2004 Keith Packard and Bart Massey.
@@ -1170,7 +1170,7 @@ RaiseException (Value thread, SymbolPtr except, Value args, InstPtr *next)
 	    int	    dim = ArrayLimits(&args->array)[0];
 	    for (i = 0; i < dim; i++)
 	    {
-		PrintError ("%g", ArrayValueGet (&args->array, i));
+		PrintError ("%g", ArrayValue (&args->array, i));
 		if (i < dim - 1)
 		    PrintError (", ");
 	    }
